ErrorSeverity

Enum ErrorSeverity 

#[non_exhaustive]
pub enum ErrorSeverity { Critical, Error, Warning, Info, }
Severity level for logging and alerting decisions.

Use LlmError::severity() to get the severity for any error.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Critical

System is unusable or data integrity is at risk.

Requires immediate attention. Page on-call if configured.



Error

Action failed but system is stable.

Should be logged and investigated but not urgent.



Warning

Unexpected but recoverable situation.

Worth logging for monitoring but may not require action.



Info

Expected failure (e.g., not found, validation error).

Normal operation, log at info/debug level.